@@ -252,7 +252,7 @@ class PluginInterface(object):
         'loadTestsFromModule', 'loadTestsFromNames',
         'handleFile', 'startTestRun', 'startTest', 'stopTest',
         'loadTestsFromName', 'loadTestsFromTestCase',
-        'stopTestRun', 'matchPath', 'getTestCaseNames',
+        'stopTestRun', 'matchPath', 'matchDirPath', 'getTestCaseNames',
         'runnerCreated', 'resultCreated', 'testOutcome', 'wasSuccessful',
         'resultStop', 'setTestOutcome', 'describeTest',
         'reportStartTest', 'reportError', 'reportFailure', 'reportSkip',
@@ -260,6 +260,7 @@ class PluginInterface(object):
         'reportOtherOutcome', 'outcomeDetail', 'beforeErrorList',
         'beforeSummaryReport', 'afterSummaryReport', 'beforeInteraction',
         'afterInteraction', 'createTests', 'afterTestRun',
+        'moduleLoadedSuite', 'handleDir',
         # ... etc?
         )
     hookClass = Hook
@@ -309,7 +310,7 @@ class Event(object):
 
     """
     _attrs = ('handled',)
-    version = '0.2'
+    version = '0.4'
 
     def __init__(self, **metadata):
         self.handled = False
@@ -618,6 +619,16 @@ class LoadFromModuleEvent(Event):
         super(LoadFromModuleEvent, self).__init__(**kw)
 
 
+class ModuleSuiteEvent(Event):
+    _attrs = Event._attrs + ('loader', 'module', 'suite')
+
+    def __init__(self, loader, module, suite, **kw):
+        self.loader = loader
+        self.module = module
+        self.suite = suite
+        super(ModuleSuiteEvent, self).__init__(**kw)
+
+
 class LoadFromTestCaseEvent(Event):
     """Event fired when tests are loaded from a test case.
 
@@ -924,12 +935,17 @@ class DescribeTestEvent(Event):
        Description of the test case. Plugins can set this to change
        how tests are described in output to users.
 
+    .. attribute :: errorList
+
+       Is the event fired as part of error list output?
+
     """
     _attrs = Event._attrs + ('test', 'description')
 
-    def __init__(self, test, description=None, **kw):
+    def __init__(self, test, description=None, errorList=False, **kw):
         self.test = test
         self.description = description
+        self.errorList = errorList
         super(DescribeTestEvent, self).__init__(**kw)
 
 
